# Changelog

## 0.0.1 (2026-01-27)


### Features

* Initial setup ([689071e](https://github.com/CoreySpohn/coronachrome/commit/689071e8bcc5663192cb9a76f126e643dfda2535))


### Miscellaneous Chores

* release 0.0.1 ([d97c9aa](https://github.com/CoreySpohn/coronachrome/commit/d97c9aaa5d2b9a9f45f86a3128736157f70c005f))
